==> mediawiki-1.14.0.tgz: mediawiki/languages/messages/MessagesTokipona.php <==
<?php
/** Toki Pona (Toki Pona)
 *
 * @ingroup Language
 * @file
 *
 * @author http://tokipona.wikia.com sysops
 */

$messages = array(
# Dates
'january'   => 'tenpo mun pi nanpa wan',
'february'  => 'tenpo mun pi nanpa tu',
'march'     => 'tenpo mun pi nanpa tu wan',
'april'     => 'tenpo mun pi nanpa tu tu',
'may_long'  => 'tenpo mun pi nanpa luka',
'june'      => 'tenpo mun pi nanpa luka wan',
'july'      => 'tenpo mun pi nanpa luka tu',
'august'    => 'tenpo mun pi nanpa luka tu wan',
'september' => 'tenpo mun pi nanpa luka tu tu',
'october'   => 'tenpo mun pi nanpa luka luka',
'november'  => 'tenpo mun pi nanpa luka luka wan',
'december'  => 'tenpo mun pi nanpa luka luka tu',

# Categories related messages
'category_header'        => 'lipu lon kulupu lipu "$1"',
'subcategories'          => 'kulupu lipu lili',
'listingcontinuesabbrev' => ' li awen',

'article'    => 'lipu sona',
'newwindow'  => '(ona li open e lupa sin)',
'cancel'     => 'ike',
'mytalk'     => 'toki mi',
'navigation' => 'lipu suli',

'help'              => 'mi sona ala',
'search'            => 'o lukin jo',
'go'                => 'o tawa',
'history'           => 'o lukin e lipu ni pi tenpo pini',
'history_short'     => 'lipu ni pi tenpo pini',
'printableversion'  => 'lipu ni o kama lipu len',
'permalink'         => 'nimi open kiwen',
'edit'              => 'o ante',
'editthispage'      => 'o ante e lipu ni',
'delete'            => 'o weka',
'deletethispage'    => 'o weka e lipu ni',
'protect'           => 'mi taso o ken ante',
'protectthispage'   => 'mi taso o ken ante e lipu ni',
'unprotect'         => 'jan ali o ken ante',
'unprotectthispage' => 'jan ale o ken ante e lipu ni',
'talkpage'          => 'Talk page',
'specialpage'       => 'lipu suli',
'talk'              => 'o toki',
'toolbox'           => 'ilo',
'otherlanguages'    => 'toki ante',
'redirectedfrom'    => '(tan $1)',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'lipu sona pi toki pona li seme?',
'aboutpage'            => 'Project:lipu sona pi toki pona li seme?',
'copyright'            => 'lipu ken $1 li lawa e lipu ni.',
'currentevents'        => 'seme li sin lon ma?',
'disclaimers'          => 'wile ala',
'edithelp'             => 'mi sona ala e ante',
'mainpage'             => 'lipu lawa',
'mainpage-description' => 'lipu lawa',
'portal'               => 'lipu pi kulupu ni',
'privacy'              => 'ken pi awen weka',

'ok'            => 'pona',
'retrievedfrom' => 'tan $1',
'editsection'   => 'o ante',
'toc'           => 'poki lawa',
'showtoc'       => 'o suli e poki ni.',
'hidetoc'       => 'o lili e poki ni',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'lipu sona',
'nstab-user'      => 'lipu jan',
'nstab-special'   => 'suli',
'nstab-image'     => 'lipu nanpa',
'nstab-mediawiki' => 'nimi',
'nstab-template'  => 'lipu mama',
'nstab-help'      => 'pana pona',
'nstab-category'  => 'kulupu lipu',

# Login and logout pages
'logout'     => 'mi o tawa',
'userlogout' => 'mi o tawa',

# Edit pages
'summary'          => 'ante li seme:',
'minoredit'        => 'ante ni li lili taso',
'watchthis'        => 'mi wile sona e ante ale pi lipu ni lon tenpo kama',
'savearticle'      => 'o awen',
'preview'          => 'lukin taso',
'showpreview'      => 'mi wile lukin taso e ante',
'editing'          => 'mi ante e: $1',
'editingcomment'   => 'mi ante e lipu $1 (wan sin)',
'copyrightwarning' => "o sona e ni: ken $2 (o lukin e $1) li lawa tawa ante ali lon {{SITENAME}} li. jan li ken ante e toki sina li ken pana e ona tawa jan ante. sina wile ala e ni la, o sitelen ala lon lipu ni.<br />
kin la sina toki e ni: toki sina ni li tan sina taso anu lipu pi ken ali.
'''SINA KEN ALA LA, O PANA ALA E TOKI PI KEN LILI TAWA LIPU NI!'''",
'templatesused'    => 'lipu ni li kepeken e lipu mama ni:',

# History pages
'histfirst' => 'pini taso',
'histlast'  => 'sin taso',

# Search results
'prevn'        => 'nanpa $1 pini',
'nextn'        => 'nanpa $1 kama',
'viewprevnext' => 'o lukin e ($1) ($2) ($3).',

# Preferences page
'preferences' => 'seme li pona tawa mi',

# Recent changes
'recentchanges'   => 'lipu seme li ante?',
'minoreditletter' => 'ante lili',
'newpageletter'   => 'lipu sin',

# Recent changes linked
'recentchangeslinked' => 'ante sama',

# Upload
'upload'            => 'o pana e lipu nanpa',
'filedesc'          => 'ante li seme',
'fileuploadsummary' => 'ante li seme:',

# Random page
'randompage' => 'mi wile lukin e lipu ante',

# Miscellaneous special pages
'lonelypages'  => 'lipu ni li jo ala e lipu sama',
'move'         => 'o tawa',
'movethispage' => 'o pana e nimi sin',

# Special:AllPages
'allpages' => 'lipu ale',

# Special:Categories
'categories' => 'kulupu lipu',

# Watchlist
'watchlist'       => 'mi sona e ante pi lipu seme',
'watch'           => 'o sona e ante',
'watchthispage'   => 'mi wile sona e ante ale pi lipu ni lon tenpo kama',
'unwatchthispage' => 'mi wile ala sona e ante ale pi lipu ni lon tenpo kama',
'watchnochange'   => 'None of your watched items was edited in the time period displayed.',

# Contributions
'mycontris' => 'mi ante e lipu seme',

# What links here
'whatlinkshere' => 'lipu seme li tawa ni?',

# Special:SpecialPages
'specialpages' => 'lipu suli',

);

==> mediawiki-1.15.1.tgz: mediawiki/languages/messages/MessagesTokipona.php <==
<?php
/** Toki Pona (Toki Pona)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author http://tokipona.wikia.com sysops
 */

$messages = array(
# Dates
'january'   => 'tenpo mun pi nanpa wan',
'february'  => 'tenpo mun pi nanpa tu',
'march'     => 'tenpo mun pi nanpa tu wan',
'april'     => 'tenpo mun pi nanpa tu tu',
'may_long'  => 'tenpo mun pi nanpa luka',
'june'      => 'tenpo mun pi nanpa luka wan',
'july'      => 'tenpo mun pi nanpa luka tu',
'august'    => 'tenpo mun pi nanpa luka tu wan',
'september' => 'tenpo mun pi nanpa luka tu tu',
'october'   => 'tenpo mun pi nanpa luka luka',
'november'  => 'tenpo mun pi nanpa luka luka wan',
'december'  => 'tenpo mun pi nanpa luka luka tu',

# Categories related messages
'category_header'        => 'lipu lon kulupu lipu "$1"',
'subcategories'          => 'kulupu lipu lili',
'listingcontinuesabbrev' => ' li awen',

'article'    => 'lipu sona',
'newwindow'  => '(ona li open e lupa sin)',
'cancel'     => 'ike',
'mytalk'     => 'toki mi',
'navigation' => 'lipu suli',

'help'              => 'mi sona ala',
'search'            => 'o lukin jo',
'go'                => 'o tawa',
'history'           => 'o lukin e lipu ni pi tenpo pini',
'history_short'     => 'lipu ni pi tenpo pini',
'printableversion'  => 'lipu ni o kama lipu len',
'permalink'         => 'nimi open kiwen',
'edit'              => 'o ante',
'editthispage'      => 'o ante e lipu ni',
'delete'            => 'o weka',
'deletethispage'    => 'o weka e lipu ni',
'protect'           => 'mi taso o ken ante',
'protectthispage'   => 'mi taso o ken ante e lipu ni',
'unprotect'         => 'jan ali o ken ante',
'unprotectthispage' => 'jan ale o ken ante e lipu ni',
'talkpage'          => 'Talk page',
'specialpage'       => 'lipu suli',
'talk'              => 'o toki',
'toolbox'           => 'ilo',
'otherlanguages'    => 'toki ante',
'redirectedfrom'    => '(tan $1)',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'lipu sona pi toki pona li seme?',
'aboutpage'            => 'Project:lipu sona pi toki pona li seme?',
'copyright'            => 'lipu ken $1 li lawa e lipu ni.',
'currentevents'        => 'seme li sin lon ma?',
'disclaimers'          => 'wile ala',
'edithelp'             => 'mi sona ala e ante',
'mainpage'             => 'lipu lawa',
'mainpage-description' => 'lipu lawa',
'portal'               => 'lipu pi kulupu ni',
'privacy'              => 'ken pi awen weka',

'ok'            => 'pona',
'retrievedfrom' => 'tan $1',
'editsection'   => 'o ante',
'toc'           => 'poki lawa',
'showtoc'       => 'o suli e poki ni.',
'hidetoc'       => 'o lili e poki ni',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'lipu sona',
'nstab-user'      => 'lipu jan',
'nstab-special'   => 'suli',
'nstab-image'     => 'lipu nanpa',
'nstab-mediawiki' => 'nimi',
'nstab-template'  => 'lipu mama',
'nstab-help'      => 'pana pona',
'nstab-category'  => 'kulupu lipu',

# Login and logout pages
'logout'     => 'mi o tawa',
'userlogout' => 'mi o tawa',

# Edit pages
'summary'          => 'ante li seme:',
'minoredit'        => 'ante ni li lili taso',
'watchthis'        => 'mi wile sona e ante ale pi lipu ni lon tenpo kama',
'savearticle'      => 'o awen',
'preview'          => 'lukin taso',
'showpreview'      => 'mi wile lukin taso e ante',
'editing'          => 'mi ante e: $1',
'editingcomment'   => 'mi ante e lipu $1 (wan sin)',
'copyrightwarning' => "o sona e ni: ken $2 (o lukin e $1) li lawa tawa ante ali lon {{SITENAME}} li. jan li ken ante e toki sina li ken pana e ona tawa jan ante. sina wile ala e ni la, o sitelen ala lon lipu ni.<br />
kin la sina toki e ni: toki sina ni li tan sina taso anu lipu pi ken ali.
'''SINA KEN ALA LA, O PANA ALA E TOKI PI KEN LILI TAWA LIPU NI!'''",
'templatesused'    => 'lipu ni li kepeken e lipu mama ni:',

# History pages
'histfirst' => 'pini taso',
'histlast'  => 'sin taso',

# Search results
'prevn'        => 'nanpa $1 pini',
'nextn'        => 'nanpa $1 kama',
'viewprevnext' => 'o lukin e ($1) ($2) ($3).',

# Preferences page
'preferences' => 'seme li pona tawa mi',

# Recent changes
'recentchanges'   => 'lipu seme li ante?',
'minoreditletter' => 'ante lili',
'newpageletter'   => 'lipu sin',

# Recent changes linked
'recentchangeslinked' => 'ante sama',

# Upload
'upload'            => 'o pana e lipu nanpa',
'filedesc'          => 'ante li seme',
'fileuploadsummary' => 'ante li seme:',

# Random page
'randompage' => 'mi wile lukin e lipu ante',

# Miscellaneous special pages
'lonelypages'  => 'lipu ni li jo ala e lipu sama',
'move'         => 'o tawa',
'movethispage' => 'o pana e nimi sin',

# Special:AllPages
'allpages' => 'lipu ale',

# Special:Categories
'categories' => 'kulupu lipu',

# Watchlist
'watchlist'       => 'mi sona e ante pi lipu seme',
'watch'           => 'o sona e ante',
'watchthispage'   => 'mi wile sona e ante ale pi lipu ni lon tenpo kama',
'unwatchthispage' => 'mi wile ala sona e ante ale pi lipu ni lon tenpo kama',
'watchnochange'   => 'None of your watched items was edited in the time period displayed.',

# Contributions
'mycontris' => 'mi ante e lipu seme',

# What links here
'whatlinkshere' => 'lipu seme li tawa ni?',

# Special:SpecialPages
'specialpages' => 'lipu suli',

);
